@@ -20,8 +20,10 @@
 #include "profilesx-profile-data.h"
 #include <libprofile.h>
 #include <keys_nokia.h>
+#include <gconf/gconf-client.h>
 
 #define PROFILESX_SETTINGS_FILE "/.profilesx"
+#define GC_ROOT "/apps/maemo/profilesx"
 
 gchar*
 load_icon_name(const gchar* profile_name)
@@ -70,6 +72,34 @@ store_icon_name(const gchar* profile_name, const gchar* icon_name)
   g_key_file_free(key_file);
 }
 
+static
+void 
+store_gconf_settings(const gchar* profile_name,
+		    profilesx_profile_data* profile_data)
+{
+  GConfClient* client = gconf_client_get_default();
+  g_assert(GCONF_IS_CLIENT(client));
+  gchar* profile_name_key = gconf_escape_key(profile_name, -1);
+  if(!profile_data->autoanswer &&
+     !profile_data->turn_speaker_on)
+  {
+    gchar* profile_conf_key = g_strdup_printf("%s/%s", GC_ROOT, profile_name_key);
+    gconf_client_recursive_unset(client, profile_conf_key, GCONF_UNSET_INCLUDING_SCHEMA_NAMES, NULL);
+    g_free(profile_conf_key);
+  }
+  else
+  {
+    gchar* autoanswer_conf_key = g_strdup_printf("%s/%s/autoAnswer", GC_ROOT, profile_name_key);
+    gchar* turnspeakeron_conf_key = g_strdup_printf("%s/%s/turnSpeakerOn", GC_ROOT, profile_name_key);
+    gconf_client_set_bool(client, autoanswer_conf_key, profile_data->autoanswer, NULL);
+    gconf_client_set_bool(client, turnspeakeron_conf_key, profile_data->turn_speaker_on, NULL);
+    g_free(turnspeakeron_conf_key);
+    g_free(autoanswer_conf_key);
+  }
+  g_free(profile_name_key);
+  g_object_unref(client);
+}
+
 void
 profilesx_store_profile_data(const gchar* profile_name,
 			    profilesx_profile_data* profile_data)
@@ -123,8 +153,30 @@ profilesx_store_profile_data(const gchar* profile_name,
 
   store_icon_name(profile_name,
 		  profile_data->status_bar_icon_name);
+  store_gconf_settings(profile_name,
+		       profile_data);
 }
 
+static
+void 
+load_gconf_settings(const gchar* profile_name,
+		    profilesx_profile_data* profile_data)
+{
+  GConfClient* client = gconf_client_get_default();
+  
+  g_assert(GCONF_IS_CLIENT(client));
+
+  gchar* profile_name_key = gconf_escape_key(profile_name, -1);
+  gchar* autoanswer_conf_key = g_strdup_printf("%s/%s/autoAnswer", GC_ROOT, profile_name_key);
+  gchar* turnspeakeron_conf_key = g_strdup_printf("%s/%s/turnSpeakerOn", GC_ROOT, profile_name_key);
+  profile_data->autoanswer = gconf_client_get_bool(client, autoanswer_conf_key, NULL);
+  profile_data->turn_speaker_on = gconf_client_get_bool(client, turnspeakeron_conf_key, NULL);
+  g_free(turnspeakeron_conf_key);
+  g_free(autoanswer_conf_key);
+  g_free(profile_name_key);
+  g_object_unref(client);
+}
+			      
 void
 profilesx_load_profile_data(const gchar* profile_name,
 			    profilesx_profile_data* profile_data)
@@ -167,7 +219,8 @@ profilesx_load_profile_data(const gchar* profile_name,
   profile_data->system_sound_level = profile_get_value_as_int(profile_name,
 							      PROFILEKEY_SYSTEM_SOUND_LEVEL);
   
-  profile_data->status_bar_icon_name = load_icon_name(profile_name);  
+  profile_data->status_bar_icon_name = load_icon_name(profile_name);
+  load_gconf_settings(profile_name, profile_data);
 }
 
 void
